<?php

namespace App\Service;

use App\Entity\InterfaceDataEntity;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Validator\Validation;

class ValidationService
{
    /**
     * Валидирование содержимого модели согласно атрибутам парамтров
     * @param InterfaceDataEntity $model
     * @return void
     */
    public function validate(InterfaceDataEntity $model): void
    {
        $validator = Validation::createValidator();
        $errors = $validator->validate($model);

        $messages = [
            'message' => 'validation_fail',
            'errors' => [],
        ];

        foreach ($errors as $error) {
            $messages['errors'][] = [
                'property' => $error->getPropertyPath(),
                'value' => $error->getInvalidValue(),
                'message' => $error->getMessage(),
            ];
        }

        if (count($messages['errors']) > 0) {
            $response = new JsonResponse($messages, 400);
            $response->send();

            exit;
        }
    }
}